@@ -26,8 +26,10 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     ui->setupUi(this);
 
     QSettings settings;
-    bool subTaxValue = settings.value("subtractTaxFromTotal").toBool();
-    ui->subTaxCheckBox->setChecked(subTaxValue);
+    bool subtractTax = settings.value("subtractTaxFromTotal").toBool();
+    ui->subTaxCheckBox->setChecked(subtractTax);
+    bool roundToQuarter = settings.value("RoundToQuarter").toBool();
+    ui->roundToQuarter->setChecked(roundToQuarter);
 }
 
 SettingsDialog::~SettingsDialog()
@@ -47,8 +49,17 @@ void SettingsDialog::changeEvent(QEvent *e)
     }
 }
 
-void SettingsDialog::on_subTaxCheckBox_stateChanged(int )
+void SettingsDialog::on_subTaxCheckBox_toggled(bool checked)
 {
-    QSettings settings;
-    settings.setValue("subtractTaxFromTotal", ui->subTaxCheckBox->isChecked());
+    settings.setValue("subtractTaxFromTotal", checked);
+}
+
+void SettingsDialog::on_roundToQuarter_clicked(bool checked)
+{
+    settings.setValue("RoundToQuarter", checked);
+}
+
+void SettingsDialog::on_roundToWhole_clicked(bool checked)
+{
+    settings.setValue("RoundToQuarter", !checked);
 }
