@@ -40,7 +40,9 @@ private:
     QSettings settings;
 
 private slots:
-    void on_subTaxCheckBox_stateChanged(int );
+    void on_roundToWhole_clicked(bool checked);
+    void on_roundToQuarter_clicked(bool checked);
+    void on_subTaxCheckBox_toggled(bool checked);
 };
 
 #endif // SETTINGSDIALOG_H
