@@ -41,25 +41,32 @@ protected:
 
 private:
     Ui::TipQalc *ui;
+    QSettings settings;
     int inputFieldId;
     float total;
     float personTotal;
     float personTip;
-    QSettings settings;
     QLineEdit *editableLine;
     SettingsDialog settingsDialog;
     AboutDialog aboutDialog;
+    int useTax;
 
     bool eventFilter(QObject *object, QEvent *event);
     void insertInField(QString value);
     void adjustPersons(int);
     void adjustTip(int);
     float round(float x, int precision);
+    float roundWeighted( float x);
+    float roundToQuarter(float x);
+    QString floatToDisplay(float n);
+    void resetResults();
     void calculateTip();
     void adjustCursorPosition();
     void manageTaxInputWidgets();
 
 private slots:
+    void on_roundTipButton_clicked();
+    void on_roundTotalButton_clicked();
     void on_calculateButton_clicked();
     void on_tipMinusButton_clicked();
     void on_tipAddButton_clicked();
@@ -67,8 +74,6 @@ private slots:
     void on_personsAddButton_clicked();
     void showSettingsDialog();
     void showAboutDialog();
-    void roundTotal();
-    void roundTip();
 
 public slots:
     void numberClicked(QString value);
